@@ -1,5 +1,6 @@
 from argparse import ArgumentError, ArgumentTypeError
 from tap._version import __version__
 from tap.tap import Tap
+from tap.tapify import tapify
 
-__all__ = ['ArgumentError', 'ArgumentTypeError', 'Tap', '__version__']
+__all__ = ['ArgumentError', 'ArgumentTypeError', 'Tap', 'tapify', '__version__']
