@@ -1,13 +1,13 @@
+import json
+import sys
+import time
 from argparse import ArgumentParser, ArgumentTypeError
 from collections import OrderedDict
 from copy import deepcopy
 from functools import partial
-import json
 from pathlib import Path
 from pprint import pformat
 from shlex import quote, split
-import sys
-import time
 from types import MethodType
 from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Tuple, TypeVar, Union, get_type_hints
 from typing_inspect import is_literal_type
@@ -21,6 +21,7 @@ from tap.utils import (
     get_origin,
     GitInfo,
     is_option_arg,
+    is_positional_arg,
     type_to_str,
     get_literals,
     boolean_type,
@@ -95,6 +96,9 @@ class Tap(ArgumentParser):
         # Get annotations from self and all super classes up through tap
         self._annotations = self._get_annotations()
 
+        # Set the default description to be the docstring
+        kwargs.setdefault('description', self.__doc__)
+
         # Initialize the super class, i.e. ArgumentParser
         super(Tap, self).__init__(*args, **kwargs)
 
@@ -156,7 +160,7 @@ class Tap(ArgumentParser):
                 kwargs['help'] += type_to_str(self._annotations[variable]) + ', '
 
             # Required/default
-            if kwargs.get('required', False):
+            if kwargs.get('required', False) or is_positional_arg(*name_or_flags):
                 kwargs['help'] += 'required'
             else:
                 kwargs['help'] += f'default={kwargs.get("default", None)}'
@@ -222,23 +226,23 @@ class Tap(ArgumentParser):
                     loop = False
                     types = get_args(var_type)
 
-                    # Don't allow Tuple[()]
-                    if len(types) == 1 and types[0] == tuple():
-                        raise ArgumentTypeError('Empty Tuples (i.e. Tuple[()]) are not a valid Tap type '
-                                                'because they have no arguments.')
-
                     # Handle Tuple[type, ...]
                     if len(types) == 2 and types[1] == Ellipsis:
                         types = types[0:1]
                         loop = True
                         kwargs['nargs'] = '*'
+                    # Handle Tuple[()]
+                    elif len(types) == 1 and types[0] == tuple():
+                        types = [str]
+                        loop = True
+                        kwargs['nargs'] = '*'
                     else:
                         kwargs['nargs'] = len(types)
 
                     var_type = TupleTypeEnforcer(types=types, loop=loop)
 
                 if get_origin(var_type) in BOXED_TYPES:
-                    # If List or Set type, set nargs
+                    # If List or Set or Tuple type, set nargs
                     if (get_origin(var_type) in BOXED_COLLECTION_TYPES
                             and kwargs.get('action') not in {'append', 'append_const'}):
                         kwargs['nargs'] = kwargs.get('nargs', '*')
@@ -255,6 +259,7 @@ class Tap(ArgumentParser):
                     # Handle the cases of List[bool], Set[bool], Tuple[bool]
                     if var_type == bool:
                         var_type = boolean_type
+
                 # If bool then set action, otherwise set type
                 if var_type == bool:
                     if explicit_bool:
@@ -298,19 +303,15 @@ class Tap(ArgumentParser):
             if variable not in self.class_variables:
                 self._add_argument(*name_or_flags, **kwargs)
 
-    def add_arguments(self) -> None:
-        """Deprecated and will be removed by January 1st, 2021.
-
-        Explicitly add arguments to the argument buffer if not using default settings.
-        """
-        pass
-
     def process_args(self) -> None:
         """Perform additional argument processing and/or validation."""
         pass
 
     def add_subparser(self, flag: str, subparser_type: type, **kwargs) -> None:
         """Add a subparser to the collection of subparsers"""
+        help_desc = kwargs.get('help', subparser_type.__doc__)
+        kwargs['help'] = help_desc
+        
         self._subparser_buffer.append((flag, subparser_type, kwargs))
 
     def _add_subparsers(self) -> None:
@@ -332,12 +333,6 @@ class Tap(ArgumentParser):
         # Call the user-defined configuration
         self.configure()
 
-        # Support the previous add_arguments interface with a deprecation warning
-        if self.__class__.add_arguments != Tap.add_arguments:
-            warn('add_arguments is deprecated and will be removed on January 1st, 2021'
-                 ' please override "configure" instead and call add_argument there. ')
-            self.add_arguments()
-
         # Add arguments to self
         self._add_arguments()
 
@@ -414,8 +409,8 @@ class Tap(ArgumentParser):
 
         :param args: List of strings to parse. The default is taken from `sys.argv`.
         :param known_only: If true, ignores extra arguments and only parses known arguments.
-        Unparsed arguments are saved to self.extra_args.
-        :legacy_config_parsing: If true, config files are parsed using `str.split` instead of `shlex.split`.
+                           Unparsed arguments are saved to self.extra_args.
+        :param legacy_config_parsing: If true, config files are parsed using `str.split` instead of `shlex.split`.
         :return: self, which is a Tap instance containing all of the parsed args.
         """
         # Prevent double parsing
