@@ -171,6 +171,15 @@ def is_option_arg(*name_or_flags) -> bool:
     return any(name_or_flag.startswith('-') for name_or_flag in name_or_flags)
 
 
+def is_positional_arg(*name_or_flags) -> bool:
+    """Returns whether the argument is a positional arg (as opposed to an optional arg).
+
+    :param name_or_flags: Either a name or a list of option strings, e.g. foo or -f, --foo.
+    :return: True if the argument is a positional arg, False otherwise.
+    """
+    return not is_option_arg(*name_or_flags)
+
+
 def tokenize_source(obj: object) -> Generator:
     """Returns a generator for the tokens of the object's source code."""
     source = inspect.getsource(obj)
@@ -181,8 +190,11 @@ def tokenize_source(obj: object) -> Generator:
 
 def get_class_column(obj: type) -> int:
     """Determines the column number for class variables in a class."""
+    first_line = 1
     for token_type, token, (start_line, start_column), (end_line, end_column), line in tokenize_source(obj):
-        if start_line == 1 or token.strip() == '':
+        if token.strip() == '@':
+            first_line += 1
+        if start_line <= first_line or token.strip() == '':
             continue
 
         return start_column
@@ -226,9 +238,10 @@ def get_class_variables(cls: type) -> OrderedDict:
             # Extract multiline comments
             if (class_variable is not None
                     and token['token_type'] == tokenize.STRING
-                    and token['token'][:3] in {'"""', "'''"}):
+                    and token['token'][:1] in {'"', "'"}):
                 sep = ' ' if variable_to_comment[class_variable]['comment'] else ''
-                variable_to_comment[class_variable]['comment'] += sep + token['token'][3:-3].strip()
+                quote_char = token['token'][:1]
+                variable_to_comment[class_variable]['comment'] += sep + token['token'].strip(quote_char).strip()
 
             # Match class variable
             class_variable = None
